@@ -2,9 +2,9 @@ from pydantic import BaseModel
 import inspect
 import ast
 import os
+from . import globals
 
 class Config(BaseModel):
-
     # NOTE: should be in sync with ui.run arguments
     host: str = '0.0.0.0'
     port: int = 80
@@ -12,6 +12,7 @@ class Config(BaseModel):
     favicon: str = 'favicon.ico'
     reload: bool = True
     show: bool = True
+    uvicorn_logging_level = 'warning'
     interactive: bool = False
 
 
@@ -58,3 +59,5 @@ os.environ['HOST'] = config.host
 os.environ['PORT'] = str(config.port)
 os.environ["STATIC_DIRECTORY"] = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'static')
 os.environ["TEMPLATES_DIRECTORY"] = os.path.join(os.environ["STATIC_DIRECTORY"], 'templates')
+
+globals.config = config
