@@ -4,7 +4,9 @@ from .group import Group
 class Column(Group):
 
     def __init__(self):
+        '''Row Element
 
+        Provides a container which arranges its child in a row.
+        '''
         view = jp.QDiv(classes='column items-start', style='gap: 1em', delete_flag=False)
-
         super().__init__(view)
