@@ -1,5 +1,5 @@
 import justpy as jp
-from typing import Callable
+from typing import Awaitable, Callable, Optional, Union
 from .value_element import ValueElement
 
 class FloatElement(ValueElement):
@@ -9,15 +9,13 @@ class FloatElement(ValueElement):
                  *,
                  value: float,
                  format: str = None,
-                 on_change: Callable,
+                 on_change: Optional[Union[Callable, Awaitable]],
                  ):
-
         self.format = format
 
         super().__init__(view, value=value, on_change=on_change)
 
     def value_to_view(self, value: float):
-
         if value is None:
             return None
         elif self.format is None:
