@@ -1,11 +1,15 @@
-from typing import Callable, Dict
+from typing import Callable, Optional
 from .custom_view import CustomView
 from .element import Element
 
 class JoystickView(CustomView):
 
-    def __init__(self, on_start, on_move, on_end, **options):
-
+    def __init__(self,
+                 on_start: Optional[Callable],
+                 on_move: Optional[Callable],
+                 on_end: Optional[Callable],
+                 **options,
+                 ):
         super().__init__('joystick', __file__, ['nipplejs.min.js'], **options)
 
         self.on_start = on_start
@@ -18,19 +22,16 @@ class JoystickView(CustomView):
                         onEnd=self.handle_end)
 
     def handle_start(self, msg):
-
         if self.on_start is not None:
             return self.on_start(msg)
         return False
 
     def handle_move(self, msg):
-
         if self.on_move is not None:
             return self.on_move(msg)
         return False
 
     def handle_end(self, msg):
-
         if self.on_end is not None:
             return self.on_end(msg)
         return False
@@ -39,10 +40,10 @@ class Joystick(Element):
 
     def __init__(self,
                  *,
-                 on_start: Callable = None,
-                 on_move: Callable = None,
-                 on_end: Callable = None,
-                 **options: Dict,
+                 on_start: Optional[Callable] = None,
+                 on_move: Optional[Callable] = None,
+                 on_end: Optional[Callable] = None,
+                 **options: dict,
                  ):
         """Joystick
 
@@ -53,5 +54,4 @@ class Joystick(Element):
         :param on_end: callback for when the user releases the joystick
         :param options: arguments like `color` which should be passed to the `underlying nipple.js library <https://github.com/yoannmoinet/nipplejs#options>`_
         """
-
         super().__init__(JoystickView(on_start, on_move, on_end, **options))
