@@ -5,7 +5,7 @@ class Menu(Group):
 
     def __init__(self,
                  *,
-                 value: bool = False
+                 value: bool = False,
                  ):
         """Menu
 
@@ -13,15 +13,12 @@ class Menu(Group):
 
         :param value: whether the menu is already opened (default: False)
         """
-
         view = jp.QMenu(value=value)
 
         super().__init__(view)
 
     def open(self):
-
         self.view.value = True
 
     def close(self):
-
         self.view.value = False
