@@ -1,13 +1,14 @@
-from typing import Callable
+from typing import Callable, Optional
 import traceback
 from .element import Element
 from .custom_view import CustomView
 from .page import Page
 from .scene_object3d import Object3D
+from ..globals import view_stack
 
 class SceneView(CustomView):
 
-    def __init__(self, *, width: int, height: int, on_click: Callable):
+    def __init__(self, *, width: int, height: int, on_click: Optional[Callable]):
         dependencies = ['three.min.js', 'OrbitControls.js', 'STLLoader.js']
         super().__init__('scene', __file__, dependencies, width=width, height=height)
         self.on_click = on_click
@@ -33,7 +34,6 @@ class SceneView(CustomView):
             traceback.print_exc()
 
 class Scene(Element):
-
     from .scene_objects import Group as group
     from .scene_objects import Box as box
     from .scene_objects import Sphere as sphere
@@ -44,7 +44,7 @@ class Scene(Element):
     from .scene_objects import Curve as curve
     from .scene_objects import Texture as texture
 
-    def __init__(self, width: int = 400, height: int = 300, on_click: Callable = None):
+    def __init__(self, width: int = 400, height: int = 300, on_click: Optional[Callable] = None):
         """3D Scene
 
         Display a 3d scene using `three.js <https://threejs.org/>`_.
@@ -59,14 +59,14 @@ class Scene(Element):
         super().__init__(SceneView(width=width, height=height, on_click=on_click))
 
     def __enter__(self):
-        self.view_stack.append(self.view)
+        view_stack.append(self.view)
         scene = self.view.objects.get('scene', SceneObject(self.view, self.page))
         Object3D.stack.clear()
         Object3D.stack.append(scene)
         return self
 
     def __exit__(self, *_):
-        self.view_stack.pop()
+        view_stack.pop()
 
 class SceneObject:
 
