@@ -1,3 +1,4 @@
+from __future__ import annotations
 from typing import Optional
 from .scene_object3d import Object3D
 
@@ -46,7 +47,7 @@ class Cylinder(Object3D):
 class Extrusion(Object3D):
 
     def __init__(self,
-                 outline: list[tuple[float, float]],
+                 outline: list[list[float, float]],
                  height: float,
                  wireframe: bool = False,
                  ):
@@ -63,18 +64,18 @@ class Stl(Object3D):
 class Line(Object3D):
 
     def __init__(self,
-                 start: tuple[float, float, float],
-                 end: tuple[float, float, float],
+                 start: list[float, float, float],
+                 end: list[float, float, float],
                  ):
         super().__init__('line', start, end)
 
 class Curve(Object3D):
 
     def __init__(self,
-                 start: tuple[float, float, float],
-                 control1: tuple[float, float, float],
-                 control2: tuple[float, float, float],
-                 end: tuple[float, float, float],
+                 start: list[float, float, float],
+                 control1: list[float, float, float],
+                 control2: list[float, float, float],
+                 end: list[float, float, float],
                  num_points: int = 20,
                  ):
         super().__init__('curve', start, control1, control2, end, num_points)
@@ -83,6 +84,6 @@ class Texture(Object3D):
 
     def __init__(self,
                  url: str,
-                 coordinates: list[list[Optional[tuple[float]]]],
+                 coordinates: list[list[Optional[list[float]]]],
                  ):
         super().__init__('texture', url, coordinates)
