@@ -1,18 +1,14 @@
 #!/usr/bin/env python3
 from typing import Awaitable, Callable
 import asyncio
-import binding
 
 from .ui import Ui  # NOTE: before justpy
 import justpy as jp
 from .timer import Timer
+from . import globals
+from . import binding
 
 
-async def binding_loop():
-    while True:
-        binding.update()
-        await asyncio.sleep(0.1)
-
 def create_task(coro):
     loop = asyncio.get_event_loop()
     return loop.create_task(coro)
@@ -24,7 +20,7 @@ def startup():
     tasks.extend(create_task(t) for t in Timer.tasks)
     tasks.extend(create_task(t) for t in Ui.startup_tasks if isinstance(t, Awaitable))
     [t() for t in Ui.startup_tasks if isinstance(t, Callable)]
-    jp.run_task(binding_loop())
+    jp.run_task(binding.loop())
 
 @jp.app.on_event('shutdown')
 def shutdown():
@@ -33,11 +29,9 @@ def shutdown():
     [t.cancel() for t in tasks]
 
 
-app = jp.app
-ui = Ui(app)
+app = globals.app = jp.app
+ui = Ui()
 
-ui.page.default_title = ui.config.title
-ui.page.default_favicon = ui.config.favicon
 page = ui.page('/')
 page.__enter__()
 jp.justpy(lambda: page, start_server=False)
