@@ -2,15 +2,14 @@ import asyncio
 import time
 import traceback
 from typing import Awaitable, Callable, Union
-from binding import BindableProperty
-from .elements.element import Element
-from .utils import handle_exceptions, handle_awaitable
+
+from .binding import BindableProperty
+from .globals import view_stack
 
 class Timer:
-
     tasks = []
 
-    active = BindableProperty
+    active = BindableProperty()
 
     def __init__(self, interval: float, callback: Union[Callable, Awaitable], *, active: bool = True, once: bool = False):
         """Timer
@@ -25,22 +24,29 @@ class Timer:
         :param once: whether the callback is only executed once after a delay specified by `interval`; default is `False`
         """
 
-        parent = Element.view_stack[-1]
+        parent = view_stack[-1]
         self.active = active
 
-        async def timeout():
+        async def do_callback():
+            try:
+                if asyncio.iscoroutinefunction(callback):
+                    return await callback()
+                else:
+                    return callback()
+            except Exception:
+                traceback.print_exc()
 
+        async def timeout():
             await asyncio.sleep(interval)
-            await handle_exceptions(handle_awaitable(callback))()
+            await do_callback()
             await parent.update()
 
         async def loop():
-
             while True:
                 try:
                     start = time.time()
                     if self.active:
-                        needs_update = await handle_exceptions(handle_awaitable(callback))()
+                        needs_update = await do_callback()
                         if needs_update != False:
                             await parent.update()
                     dt = time.time() - start
