@@ -1,6 +1,6 @@
 class Ui:
-
-    from .run import run, config  # NOTE: before justpy
+    from .config import config  # NOTE: before run
+    from .run import run  # NOTE: before justpy
 
     from .elements.button import Button as button
     from .elements.checkbox import Checkbox as checkbox
@@ -16,6 +16,8 @@ class Ui:
     from .elements.log import Log as log
     from .elements.markdown import Markdown as markdown
     from .elements.menu import Menu as menu
+    from .elements.menu_item import MenuItem as menu_item
+    from .elements.menu_separator import MenuSeparator as menu_separator
     from .elements.notify import Notify as notify
     from .elements.number import Number as number
     from .elements.page import Page as page
@@ -34,14 +36,11 @@ class Ui:
     from .elements.row import Row as row
     from .elements.column import Column as column
     from .elements.card import Card as card
+    from .elements.keyboard import Keyboard as keyboard
+    from .elements.card import CardSection as card_section
 
     from .timer import Timer as timer
 
     from .lifecycle import startup_tasks, on_startup, shutdown_tasks, on_shutdown
 
-    def __init__(self, app) -> None:
-        self.app = app
-        
-
-    def add_route(self, route):
-        self.app.routes.insert(0, route)
\ No newline at end of file
+    from .routes import add_route, get
